{ pkgs, ... }: {

  imports = [
    ../common
    ./doom-emacs.nix
    ./git.nix
    ./gpg.nix
    ./i3.nix
    ./packages
    ./ssh.nix
    ./stylix.nix
    ./vim.nix
    ./yubikey.nix
  ];

  home.stateVersion = "22.11";

  programs.htop = {
    enable = true;
    settings.highlight_base_name = true;
    settings.tree_view = true;
  };

  xdg.configFile."mimeapps.list".text = ''
    [Default Applications]
    text/html=browser-select.desktop
    x-scheme-handler/http=browser-select.desktop
    x-scheme-handler/https=browser-select.desktop
    x-scheme-handler/about=browser-select.desktop
    x-scheme-handler/mailto=thunderbird.desktop;
    x-scheme-handler/unknown=browser-select.desktop
    x-scheme-handler/postman=Postman.desktop
    image/png=sxiv.desktop
    image/jpeg=sxiv.desktop
    x-scheme-handler/magnet=userapp-transmission-gtk-YPS6F2.desktop
  '';

  xdg.configFile."khal/config".text = ''
    [calendars]

    [[local_calendar]]
    path = ~/.calendars/*
    type = discover

    [locale]
    timeformat = %H:%M
    dateformat = %Y-%m-%d
    longdateformat = %Y-%m-%d
    datetimeformat = %Y-%m-%d %H:%M
    longdatetimeformat = %Y-%m-%d %H:%M
  '';

  xdg.configFile."vdirsyncer/config".text = ''
    [general]
    # A folder where vdirsyncer can store some metadata about each pair.
    status_path = "~/.vdirsyncer/status/"

    # CALDAV
    [pair my_calendar]
    a = "nextcloud_calendar"
    b = "local_calendar"
    collections = ["from a", "from b"]

    [storage nextcloud_calendar]
    type = "caldav"
    url = "https://nextcloud.ingolf-wagner.de/"
    username = "palo"
    password.fetch = ["command", "${pkgs.pass}/bin/pass", "home/nextcloud/palo/nextcloudcmd-token"]

    [storage local_calendar]
    type = "filesystem"
    path = "~/.calendars/"
    fileext = ".ics"
  '';

}
