{ config, pkgs, lib, ... }: {

  imports = [

    ../../components
    ../../system/desktop
    ./hardware-configuration.nix

    ./packages.nix
    ./syncthing.nix
    ./tinc.nix

  ];

  sops.defaultSopsFile = ../../secrets/sternchen.yaml;
  networking.hostName = "sternchen";

  components.gui.enable = true;
  components.gui.kmonad.enable = false;

  components.terminal.enable = true;
  components.network.enable = true;
  components.network.wifi.enable = true;
  components.mainUser.enable = true;
  users.users.mainUser.extraGroups = [ "adbusers" "video" ];
  home-manager.users.mainUser.home.git-pull.enable = false;
  users.users.mainUser.name = lib.mkForce "tina";
  users.users.mainUser.home = lib.mkForce "/home/tina";

  #system.custom.wifi.interfaces = [ "wlp3s0" ];

  security.wrappers = {
    pmount = {
      source = "${pkgs.pmount}/bin/pmount";
      setuid = true;
      owner = "root";
      group = "root";
    };
    pumount = {
      source = "${pkgs.pmount}/bin/pumount";
      setuid = true;
      owner = "root";
      group = "root";
    };
  };

  programs.custom.steam.enable = false;

  # keyboard fiddling
  i18n.defaultLocale = "de_DE.UTF-8";
  console.keyMap = "de";
  services.xserver.layout = "de,us";

  #system.custom.suspend.enable = false;
  services.printing.enable = false;

  # fonts
  # -----
  programs.custom.urxvt.fontSize = 12;
  programs.custom.xterm.fontSize = 12;
  # system.custom.fonts.dpi = 100;

  # for congress and streaming
  hardware.opengl = {
    enable = true;
    #extraPackages = [ pkgs.vaapiIntel ];
    driSupport = true;
    driSupport32Bit = true;
  };

  services.xserver.displayManager.defaultSession = "plasma";

  services.xserver.desktopManager.pantheon.enable = false;
  services.xserver.desktopManager.xfce.enable = false;
  services.xserver.desktopManager.gnome.enable = false;

  services.xserver.desktopManager.cinnamon.enable = true;
  services.xserver.desktopManager.lxqt.enable = true;
  services.xserver.desktopManager.mate.enable = true;

  services.xserver.desktopManager.plasma5.enable = true;
  services.xserver.desktopManager.plasma5.phononBackend = "vlc";

  # stuff
  # -----
  custom.samba-share = {
    enable = false;
    folders = {
      share = "/home/share";
    };
  };

  virtualisation = {
    docker.enable = false;
    virtualbox = {
      host.enable = false;
      guest.x11 = false;
      guest.enable = false;
    };
  };

}

