{ config, pkgs, lib, ... }: {

  imports = [

    ../../components
    ../../system/desktop

    ./hardware-configuration.nix
    ./packages.nix
    ./syncthing.nix
    ./tinc.nix
    # ./trilium.nix

    #./wifi-access-point.nix
    #./wireshark.nix
    #./qemu.nix
    ./wireguard.nix

  ];

  components.gui.enable = true;
  components.terminal.enable = true;
  components.network.enable = true;
  components.network.wifi.enable = true;
  components.mainUser.enable = true;
  users.users.mainUser.extraGroups = [ "adbusers" "video" ];

  programs.custom.steam.enable = false;
  services.printing.enable = false;

  services.nginx.enable = true;

  networking.hostName = "sterni";

  services.flatpak.enable = true;

  security.wrappers = {
    pmount = {
      source = "${pkgs.pmount}/bin/pmount";
      setuid = true;
      owner = "root";
      group = "root";
    };
    pumount = {
      source = "${pkgs.pmount}/bin/pumount";
      setuid = true;
      owner = "root";
      group = "root";
    };
  };

  home-manager.users.mainUser.home.stateVersion = "22.11";

  # fonts
  # -----
  programs.custom.urxvt.fontSize = 12;
  programs.custom.xterm.fontSize = 12;

  virtualisation = {
    docker.enable = true;
    podman.enable = true;

    virtualbox = {
      host.enable = false;
      guest.x11 = false;
      guest.enable = false;
    };
  };

  services.xserver.desktopManager.gnome.enable = true;

  custom.samba-share = {
    enable = false;
    folders = {
      share = "/home/share";
      video = "/home/video-material";
    };
  };

  # enable this to use sidequest
  # programs.adb.enable = false;

  # for congress and streaming
  hardware.opengl = {
    enable = true;
    #  extraPackages = [
    #        intel-media-driver # LIBVA_DRIVER_NAME=iHD
    #        vaapiIntel         # LIBVA_DRIVER_NAME=i965 (older but works better for Firefox/Chromium)
    #        vaapiVdpau
    #        libvdpau-va-gl
    #  ];
    driSupport = true;
    driSupport32Bit = true;
  };

}
